@@ -102,7 +102,7 @@ summary.DSC <- function(object, ...) print(object)
 
 #plot.DSC will call super question.
 plot.DSC <- function(x, dsd = NULL, n = 500, 
-  col_points="gray",  
+  col_points=NULL,  
   col_clusters=c("red", "blue"), 
   weights=TRUE,
   scale=c(1,5),
@@ -115,6 +115,8 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
   
   type <- match.arg(type)
   
+  if(is.null(col_points)) col_points <- .points_col
+  
   if(type !="both") { 
     if(type =="auto") type <- get_type(x)
     ## method can be pairs, scatter or pc (projection with PCA)
@@ -166,7 +168,7 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
   
   ### prepend data if given
   if(!is.null(dsd)) {
-    d <- get_points(dsd, n, assignment = TRUE)
+    d <- get_points(dsd, n, cluster = TRUE)
     #	names(d) <- names(centers)
     # fix center names
     names(centers) <- names(d)
@@ -174,13 +176,13 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
     
     col <- c(rep(col_points,n)[1:n], col)
     cex_clusters <- c(rep(cex, n), cex_clusters)
-    mpch <- c(attr(d, "assignment"), mpch)
+    mpch <- c(attr(d, "cluster"), mpch)
     lwd <- c(rep(1,n), lwd)
     
     ### handle noise
     noise <- is.na(mpch)
-    mpch[noise] <- noise_pch
-    col[noise] <- noise_col
+    mpch[noise] <- .noise_pch
+    col[noise] <- .noise_col
     #cex_clusters[noise] <- cex_clusters[noise]*.5
     
   }
