@@ -17,6 +17,16 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
+### Subclasses need to implement methods for:
+# Constructor
+# method cluster for RObj
+# get_microclusters(x)
+# get_microweights(x)
+########
+
+DSC_Micro <- function(...) stop("DSC_Micro is an abstract class and cannot be instantiated!")
+
+
 get_centers.DSC_Micro <- function(x, type=c("auto", "micro", "macro"), ...) {
     type <- match.arg(type)
     if(type=="auto") type <- "micro"
