@@ -89,11 +89,13 @@ DSD_Gaussians <- function(k=2, d=2, mu, sigma, p, separation=0.2,
     p = p,
     noise = noise,
     noise_range = noise_range)
-  class(l) <- c("DSD_Gaussians","DSD_R","DSD")
+  class(l) <- c("DSD_Gaussians","DSD_R", "DSD_data.frame", "DSD")
   l
 }
 
-get_points.DSD_Gaussians <- function(x, n=1, assignment = FALSE, ...) {
+get_points.DSD_Gaussians <- function(x, n=1, 
+    outofpoints=c("stop", "warn", "ignore"), 
+    cluster = FALSE, class = FALSE, ...) {
   
   clusterOrder <- sample(x=c(1:x$k), 
     size=n, 
@@ -117,6 +119,8 @@ get_points.DSD_Gaussians <- function(x, n=1, assignment = FALSE, ...) {
   }
   
   data <- as.data.frame(data)
-  if(assignment) attr(data, "assignment") <- clusterOrder
+  if(cluster) attr(data, "cluster") <- clusterOrder
+  if(class) data <- cbind(data, class = clusterOrder)
+
   data
 }
