@@ -62,10 +62,10 @@ cluster.ani <- function(dsc=NULL, dsd, macro=NULL, n=1000,
   }
   
   for(i in 1:rounds) {
-    d <- DSD_Wrapper(dsd, n=horizon, loop=FALSE)
+    d <- DSD_Memory(dsd, n=horizon, loop=FALSE)
     
     if(!is.null(dsc)) {
-      cl <- cluster(dsc, d, horizon)
+      cl <- update(dsc, d, horizon)
       
       if(!is.null(macro)) cl <- recluster(macro, dsc)
       
